/*
 * AbstractModuleTest.java
 *
 * Copyright (c) 2004-2019, Erik C. Thauvin (erik@thauvin.net)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 *   Neither the name of this project nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.thauvin.erik.mobibot.modules;

import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * The <code>AbstractModuleTest</code> class.
 *
 * @author <a href="https://erik.thauvin.net/" target="_blank">Erik C. Thauvin</a>
 * @created 2019-04-07
 * @since 1.0
 */

final class AbstractModuleTest {
    private AbstractModuleTest() {
        throw new UnsupportedOperationException("Illegal constructor call.");
    }

    @SuppressFBWarnings("CE_CLASS_ENVY")
    static void testAbstractModule(final AbstractModule module) {
        final String name = module.getClass().getName();

        assertThat(module.isEnabled()).as(name + ": enabled").isNotEqualTo(module.hasProperties());
        assertThat(module.getCommands().size()).as(name + ": commands > 0").isGreaterThan(0);
        if (!module.hasProperties()) {
            assertThat(module.getPropertyKeys().size()).as(name + ": no properties").isEqualTo(0);
            module.setProperty("test", "test");
            module.setProperty("", "invalid");
        }

        assertThat(module.getPropertyKeys().size()).as(name + ": properties > 0").isGreaterThan(0);

        module.setProperty("invalid", "");
        assertThat(module.isValidProperties()).as(name + ": invalid properties").isFalse();
    }
}
